import { BasicParser } from '../common/BasicParser';
import { Atom } from './Atom';
export declare class MP4Parser extends BasicParser {
    private static read_BE_Signed_Integer;
    private static read_BE_Unsigned_Integer;
    private audioLengthInBytes;
    private tracks;
    parse(): Promise<void>;
    handleAtom(atom: Atom): Promise<void>;
    private getTrackDescription;
    private calculateBitRate;
    private addTag;
    private addWarning;
    /**
     * Parse data of Meta-item-list-atom (item of 'ilst' atom)
     * @param metaAtom
     * Ref: https://developer.apple.com/library/content/documentation/QuickTime/QTFF/Metadata/Metadata.html#//apple_ref/doc/uid/TP40000939-CH1-SW8
     */
    private parseMetadataItemData;
    private parseValueAtom;
    /**
     * Parse movie header (mvhd) atom
     * @param mvhd mvhd atom
     * Ref: https://developer.apple.com/library/archive/documentation/QuickTime/QTFF/QTFFChap2/qtff2.html#//apple_ref/doc/uid/TP40000939-CH204-56313
     */
    private parseAtom_mvhd;
    /**
     * Parse media header (mdhd) atom
     * @param mdhd mdhd atom
     * Ref: https://developer.apple.com/library/archive/documentation/QuickTime/QTFF/QTFFChap2/qtff2.html#//apple_ref/doc/uid/TP40000939-CH204-25615
     */
    private parseAtom_mdhd;
    private parseAtom_ftyp;
    private parseAtom_tkhd;
    /**
     * Parse sample description atom
     * @param len
     */
    private parseAtom_stsd;
    private parseAtom_stsc;
    private parseAtom_stts;
    /**
     * @param sampleDescription
     * Ref: https://developer.apple.com/library/archive/documentation/QuickTime/QTFF/QTFFChap3/qtff3.html#//apple_ref/doc/uid/TP40000939-CH205-128916
     */
    private parseSoundSampleDescription;
    /**
     * Parse chapter-list atom
     * @param chap chap atom
     */
    private parseAtom_chap;
    /**
     * Parse sample-sizes atom ('stsz')
     * @param len
     */
    private parseAtom_stsz;
    /**
     * Parse chunk-offset atom ('stco')
     * @param len
     */
    private parseAtom_stco;
    /**
     * Parse mdat atom.
     * Will scan for chapters
     * @param len
     */
    private parseAtom_mdat;
    private parseChapterTrack;
    private findSampleOffset;
    private getChunkDuration;
    private getSamplesPerChunk;
}
